#!/var/folders/k1/30mswbxs7r1g6zwn8y4fyt500000gp/T/abs_b16ne9777j/croot/anaconda-navigator_1709540442831/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/var/folders/k1/30mswbxs7r1g6zwn8y4fyt500000gp/T/abs_b16ne9777j/croot/anaconda-navigator_1709540442831/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/anaconda-navigator"])
